#
# spec file for package python-python-socketio
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-python-socketio
Version:        5.7.2
Release:        2.3
Summary:        SocketIO server
License:        MIT
URL:            http://github.com/miguelgrinberg/python-socketio/
Source:         https://github.com/miguelgrinberg/python-socketio/archive/v%{version}.tar.gz#/python-socketio-%{version}.tar.gz
BuildRequires:  %{python_module bidict >= 0.21.0}
BuildRequires:  %{python_module python-engineio >= 4.1.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
#Tests:
BuildRequires:  %{python_module msgpack}
Requires:       python-bidict >= 0.21.0
Requires:       python-python-engineio >= 4.1.0
Suggests:       python-aiohttp >= 3.4
Suggests:       python-requests >= 2.21.0
Suggests:       python-websocket-client >= 0.54.0
Suggests:       python-websockets >= 7.0
BuildArch:      noarch
BuildRequires:  %{python_module pytest}
%python_subpackages

%description
Python implementation of the Socket.IO realtime server.

%prep
%setup -q -n python-socketio-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest -rs -k 'not test_logger'

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/socketio
%{python_sitelib}/python_socketio-%{version}*-info

%changelog
* Fri Dec  1 2023 Antonio Larrosa <alarrosa@suse.com>
- Add %%{?sle15_python_module_pythons}
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 5.7.2
  * Fixed disconnect implementation when using a message queue #1002 (commit)
  * Fixed remote async disconnects via message queue #1003 (commit)
  * Support optional payloads in msgpack implementation #981 (commit) (thanks Cromfel!)
  * Recommend ASGI integration for Sanic in Documentation (commit)
* Thu Oct  6 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to Release 5.7.1 - 2022-07-15
  Add namespaces argument to Server and AsyncServer #822 (commit)
  Add missing await in asyncio server #952 (commit) (thanks sjrodahl!)
- Update to Release 5.7.0 - 2022-07-04
  Server refuses connections on unknown namespaces #822 (commit)
  Do not send ACK packet for unknown events #824 (commit)
  Fix Python 3.11 deprecation warning #941 (commit) (thanks Jérôme Boulmier!)
  Correct handling of RedisError exception #919 (commit)
  Update Django example (commit)
  Documentation fix for async client (commit)
  Update documentation of asyncio server (commit)
  Fix documentation typo #948 (commit) (thanks mostlycryptic!)
- Update to Release 5.6.0 - 2022-04-24
  Catch and log errors in pubsub listening thread #889 (commit)
  Use new asyncio support in redis package #911 (commit)
  Add support for aiopiko version 7 and higher #897 (commit) (thanks Dmitriy!)
  Fixed documentation typo #910 (commit) (thanks Omar Costa Hamido!)
  Fix aiohttp example's background task #881 (commit)
  Bump sanic from 0.8 to 20.12.6 in /examples/server/sanic #875 (commit) (thanks dependabot[bot]!)
  Add application name to Sanic example #892 (commit) (thanks Florian Metzger-Noel!)
- Update to Release 5.5.2 - 2022-02-15
  Connect with an empty auth object instead of None #861 (commit)
  Fix indentation in the "Rooms" docs example. #872 (commit) (thanks Ezio Melotti!)
  Remove 3.6 and pypy-3.6 builds, add 3.10 and pypy-3.8 (commit)
* Sun Jan 23 2022 Axel Braun <axel.braun@gmx.de>
- version 5.5.1
  * Support multiple Kafka servers (thanks sparkingdark!)
  * Include example code in flake8 pass
  * Option to disable the SIGINT handler in the client #792
  * Do not invoke reserved events on a catch-all handler #814
  * Use correct binary packet types in the msgpack packet encoder #811
  * Add missing call() method to namespace classes #800
  * Add missing to argument to namespace emit() and send() methods #810
  * Configure Redis pubsub to skip subscription messages
  * Migrate async Redis client manager to aioredis 2 #771 (thanks Sam Mosleh!)
  * Update Python supported versions in docs
  * Document how to get the connection state in the client #799
  * Improved documentation of start_background_task() function
  * Improved documentation of call() method #813
  * Fixed intermittent test failures #572
* Sat Oct 23 2021 Axel Braun <axel.braun@gmx.de>
- version 5.4.1
  * Catch-all event handlers
  * Implement disconnect method for external processes #684
* Wed Oct  6 2021 Axel Braun <axel.braun@gmx.de>
- update to version 5.4.0
  * Big changelog, see CHANGES.md
* Tue May 25 2021 Ben Greiner <code@bnavigator.de>
- Update to 5.3.0
  * Big changelog, see CHANGES.md
* Sun May 16 2021 Axel Braun <axel.braun@gmx.de>
- python2 build removed
* Sun Nov 29 2020 John Vandenberg <jayvdb@gmail.com>
- Convert to single spec
- Activate test suite
- Update to v4.6.1
* Thu Feb  1 2018 gsmith@suse.com
- Initial version 1.8.4
